@@ -5,28 +5,15 @@
   }
 }
 .hasUnits <- FALSE
-.rcppVersion <- utils::packageVersion("Rcpp")
 .PreciseSumsVersion <- utils::packageVersion("PreciseSums")
 .dparserVersion <- utils::packageVersion("dparser")
-.checkmateVersion <- utils::packageVersion("checkmate")
 .onLoad <- function(libname, pkgname) { ## nocov start
-  if (!identical(.rcppVersion, utils::packageVersion("Rcpp"))) {
-    stop("RxODE compiled with Rcpp '", as.character(.rcppVersion),
-         "' but Rcpp '", as.character(utils::packageVersion("Rcpp")), "' is loaded\nRecompile RxODE with the new version of Rcpp",
-         call.=FALSE)
-  }
   if (!identical(.dparserVersion, utils::packageVersion("dparser"))) {
     stop("RxODE compiled with dparser '", as.character(.dparserVersion),
          "' but dparser '", as.character(utils::packageVersion("dparser")),
          "' is loaded\nRecompile RxODE with the this version of dparser",
          call.=FALSE)
   }
-  if (!identical(.checkmateVersion, utils::packageVersion("checkmate"))) {
-    stop("RxODE compiled with checkmate '", as.character(.checkmateVersion),
-         "' but checkmate '", as.character(utils::packageVersion("checkmate")),
-         "' is loaded\nRecompile RxODE with the this version of checkmate",
-         call.=FALSE)
-  }
   if (!identical(.PreciseSumsVersion, utils::packageVersion("PreciseSums"))) {
     stop("RxODE compiled with PreciseSums '", as.character(.PreciseSumsVersion),
          "' but PreciseSums '", as.character(utils::packageVersion("PreciseSums")),
