@@ -38,44 +38,44 @@ void methodswitch(struct lsoda_context_t * ctx, double dsm, double pnorm, double
    If the Lipschitz constant and error estimate are not polluted
    by roundoff, perform the usual test.
    Otherwise, switch to the bdf methods if the last step was
-   restricted to insure stability ( _C(irflag) = 1 ), and stay with Adams
+   restricted to insure stability ( _rxC(irflag) = 1 ), and stay with Adams
    method if not.  When switching to bdf with polluted error estimates,
    in the absence of other information, double the step size.
 
    When the estimates are ok, we make the usual test by computing
    the step size we could have (ideally) used on this step,
    with the current (Adams) method, and also that for the bdf.
-   If _C(nq) > mxords, we consider changing to order mxords on switching.
+   If _rxC(nq) > mxords, we consider changing to order mxords on switching.
    Compare the two step sizes to decide whether to switch.
    The step size advantage must be at least ratio = 5 to switch.
 */
-	if (_C(meth) == 1) {
-		if (_C(nq) > 5)
+	if (_rxC(meth) == 1) {
+		if (_rxC(nq) > 5)
 			return;
-		if (dsm <= (100. * pnorm * ETA) || _C(pdest) == 0.) {
-			if (_C(irflag) == 0)
+		if (dsm <= (100. * pnorm * ETA) || _rxC(pdest) == 0.) {
+			if (_rxC(irflag) == 0)
 				return;
 			rh2 = 2.;
-			nqm2 = min(_C(nq), mxords);
+			nqm2 = min(_rxC(nq), mxords);
 		} else {
-			exsm = 1. / (double) (_C(nq) + 1);
+			exsm = 1. / (double) (_rxC(nq) + 1);
 			rh1 = 1. / (1.2 * pow(dsm, exsm) + 0.0000012);
 			rh1it = 2. * rh1;
-			pdh = _C(pdlast) * fabs(_C(h));
+			pdh = _rxC(pdlast) * fabs(_rxC(h));
 			if ((pdh * rh1) > 0.00001)
-				rh1it = sm1[_C(nq)] / pdh;
+				rh1it = sm1[_rxC(nq)] / pdh;
 			rh1 = min(rh1, rh1it);
-			if (_C(nq) > mxords) {
+			if (_rxC(nq) > mxords) {
 				nqm2 = mxords;
 				lm2 = mxords + 1;
 				exm2 = 1. / (double) lm2;
 				lm2p1 = lm2 + 1;
-				dm2 = vmnorm0(neq, _C(yh)[lm2p1], _C(ewt)) / cm2[mxords];
+				dm2 = vmnorm0(neq, _rxC(yh)[lm2p1], _rxC(ewt)) / cm2[mxords];
 				rh2 = 1. / (1.2 * pow(dm2, exm2) + 0.0000012);
 			} else {
-				dm2 = dsm * (cm1[_C(nq)] / cm2[_C(nq)]);
+				dm2 = dsm * (cm1[_rxC(nq)] / cm2[_rxC(nq)]);
 				rh2 = 1. / (1.2 * pow(dm2, exsm) + 0.0000012);
-				nqm2 = _C(nq);
+				nqm2 = _rxC(nq);
 			}
 			if (rh2 < RATIO * rh1)
 				return;
@@ -84,39 +84,39 @@ void methodswitch(struct lsoda_context_t * ctx, double dsm, double pnorm, double
    The method switch test passed.  Reset relevant quantities for bdf.
 */
 		*rh = rh2;
-		_C(icount) = 20;
-		_C(meth) = 2;
-		_C(miter) = 2;
-		_C(pdlast) = 0.;
-		_C(nq) = nqm2;
+		_rxC(icount) = 20;
+		_rxC(meth) = 2;
+		_rxC(miter) = 2;
+		_rxC(pdlast) = 0.;
+		_rxC(nq) = nqm2;
 		return;
-	}			/* end if ( _C(meth) == 1 )   */
+	}			/* end if ( _rxC(meth) == 1 )   */
 	/*
 	   We are currently using a bdf method, considering switching to Adams.
 	   Compute the step size we could have (ideally) used on this step,
 	   with the current (bdf) method, and also that for the Adams.
-	   If _C(nq) > mxordn, we consider changing to order mxordn on switching.
+	   If _rxC(nq) > mxordn, we consider changing to order mxordn on switching.
 	   Compare the two step sizes to decide whether to switch.
 	   The step size advantage must be at least 5/ratio = 1 to switch.
 	   If the step size for Adams would be so small as to cause
 	   roundoff pollution, we stay with bdf.
 	*/
-	exsm = 1. / (double) (_C(nq) + 1);
-	if (mxordn < _C(nq)) {
+	exsm = 1. / (double) (_rxC(nq) + 1);
+	if (mxordn < _rxC(nq)) {
 		nqm1 = mxordn;
 		lm1 = mxordn + 1;
 		exm1 = 1. / (double) lm1;
 		lm1p1 = lm1 + 1;
-		dm1 = vmnorm0(neq, _C(yh)[lm1p1], _C(ewt)) / cm1[mxordn];
+		dm1 = vmnorm0(neq, _rxC(yh)[lm1p1], _rxC(ewt)) / cm1[mxordn];
 		rh1 = 1. / (1.2 * pow(dm1, exm1) + 0.0000012);
 	} else {
-		dm1 = dsm * (cm2[_C(nq)] / cm1[_C(nq)]);
+		dm1 = dsm * (cm2[_rxC(nq)] / cm1[_rxC(nq)]);
 		rh1 = 1. / (1.2 * pow(dm1, exsm) + 0.0000012);
-		nqm1 = _C(nq);
+		nqm1 = _rxC(nq);
 		exm1 = exsm;
 	}
 	rh1it = 2. * rh1;
-	pdh = _C(pdnorm) * fabs(_C(h));
+	pdh = _rxC(pdnorm) * fabs(_rxC(h));
 	if ((pdh * rh1) > 0.00001)
 		rh1it = sm1[nqm1] / pdh;
 	rh1 = min(rh1, rh1it);
@@ -131,11 +131,11 @@ void methodswitch(struct lsoda_context_t * ctx, double dsm, double pnorm, double
    The switch test passed.  Reset relevant quantities for Adams.
 */
 	*rh = rh1;
-	_C(icount) = 20;
-	_C(meth) = 1;
-	_C(miter) = 0;
-	_C(pdlast) = 0.;
-	_C(nq) = nqm1;
+	_rxC(icount) = 20;
+	_rxC(meth) = 1;
+	_rxC(miter) = 0;
+	_rxC(pdlast) = 0.;
+	_rxC(nq) = nqm1;
 
 }				/* end methodswitch   */
 
