@@ -11,9 +11,9 @@ int solsy(struct lsoda_context_t * ctx, double *y)
 
 /*
    This routine manages the solution of the linear system arising from
-   a chord iteration.  It is called if _C(miter) != 0.
-   If _C(miter) is 2, it calls dgesl to accomplish this.
-   If _C(miter) is 5, it calls dgbsl.
+   a chord iteration.  It is called if _rxC(miter) != 0.
+   If _rxC(miter) is 2, it calls dgesl to accomplish this.
+   If _rxC(miter) is 5, it calls dgbsl.
 
    y = the right-hand side vector on input, and the solution vector
        on output.
@@ -21,12 +21,12 @@ int solsy(struct lsoda_context_t * ctx, double *y)
 
 {
 	const int neq = ctx->neq;
-	if (_C(miter) != 2) {
+	if (_rxC(miter) != 2) {
 		/* miter has to be 2. the miter=5 case is not implemented. */
 		Rf_errorcall(R_NilValue, "liblsoda does not implement this. (solsy)");
 	}
-	if (_C(miter) == 2)
-		dgesl0(_C(wm), neq, _C(ipvt), y, 0);
+	if (_rxC(miter) == 2)
+		dgesl0(_rxC(wm), neq, _rxC(ipvt), y, 0);
 	return 1;
 
 }
